@@ -1,5 +1,5 @@
 package Email::Sender::Transport::Mailgun;
-our $VERSION = "0.02";
+our $VERSION = "0.03";
 
 use Moo;
 with 'Email::Sender::Transport';
@@ -27,7 +27,7 @@ has [qw( api_key domain )] => (
     isa => Str,
 );
 
-has [qw( campaign tag )] => (
+has [qw( tag )] => (
     is => 'ro',
     predicate => 1,
     isa => ArrayRef[Str],
@@ -81,7 +81,7 @@ has json => (
     builder => sub { JSON::MaybeXS->new },
 );
 
-# https://documentation.mailgun.com/api-sending.html#sending
+# https://documentation.mailgun.com/en/latest/api-sending.html#sending
 sub send_email {
     my ($self, $email, $env) = @_;
 
@@ -94,8 +94,7 @@ sub send_email {
     };
 
     my @options = qw(
-        campaign deliverytime dkim tag testmode
-        tracking tracking_clicks tracking_opens
+        deliverytime dkim tag testmode tracking tracking_clicks tracking_opens
     );
 
     for my $option (@options) {
@@ -142,9 +141,13 @@ sub _build_uri {
     my $self = shift;
 
     my ($proto, $rest) = split('://', $self->base_uri);
-    my $api_key = $self->api_key;
     my $domain = $self->domain;
 
+    # Percent-escape anything other than alphanumeric and - _ . ~
+    # https://github.com/sdt/Email-Sender-Transport-Mailgun/issues/4
+    my $api_key = $self->api_key;
+    $api_key =~ s/[^-_.~0-9a-zA-Z]/sprintf('%%%02x',ord($&))/eg;
+
     # adapt endpoint based on region setting.
     $rest =~ s/(\.mailgun)/sprintf('.%s%s', $self->region, $1)/e
         if defined $self->region && $self->region ne 'us';
@@ -204,20 +207,16 @@ The attributes all correspond directly to Mailgun parameters.
 
 =head2 api_key
 
-Mailgun API key. See L<https://documentation.mailgun.com/api-intro.html#authentication>
+Mailgun API key. See L<https://documentation.mailgun.com/en/latest/api-intro.html#authentication-1>
 
 =head2 domain
 
-Mailgun domain. See L<https://documentation.mailgun.com/api-intro.html#base-url>
+Mailgun domain. See L<https://documentation.mailgun.com/en/latest/api-intro.html#base-url-1>
 
 =head1 OPTIONAL ATTRIBUTES
 
 These (except region) correspond to the C<o:> options in the C<messages.mime>
-section of L<https://documentation.mailgun.com/api-sending.html#sending>
-
-=head2 campaign
-
-Id of the campaign. Comma-separated string list or arrayref of strings.
+section of L<https://documentation.mailgun.com/en/latest/api-sending.html#sending>
 
 =head2 deliverytime
 
@@ -231,7 +230,7 @@ Enables/disables DKIM signatures. C<'yes'> or C<'no'>.
 
 Defines used Mailgun region. C<'us'> (default) or C<'eu'>.
 
-See L<https://documentation.mailgun.com/en/latest/api-intro.html#mailgun-regions>.
+See L<https://documentation.mailgun.com/en/latest/api-intro.html#mailgun-regions-1>
 
 =head2 tag
 
@@ -256,7 +255,7 @@ Toggles open tracking. C<'yes'> or C<'no'>.
 =head1 MIME HEADERS
 
 The C<o:> options above can also be specified using the C<X-Mailgun-> headers
-listed here L<https://documentation.mailgun.com/user_manual.html#sending-via-smtp>
+listed here L<https://documentation.mailgun.com/en/latest/user_manual.html#sending-via-smtp>
 
 If a single-valued option is specified in both the options and the headers,
 experimentation shows the header takes precedence. This doesn't seem to be
@@ -281,8 +280,6 @@ C<EMAIL_SENDER_TRANSPORT_>.
 
 =item EMAIL_SENDER_TRANSPORT_domain
 
-=item EMAIL_SENDER_TRANSPORT_campaign
-
 =item EMAIL_SENDER_TRANSPORT_deliverytime
 
 =item EMAIL_SENDER_TRANSPORT_dkim
